/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.crypto;

import de.gematik.ti.sgd.SgdTestCryptoUtilities;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.security.cert.X509Certificate;

import static org.assertj.core.api.AssertionsForClassTypes.assertThat;

public class AdmissionParsingTest {
    {
        SgdCryptoUtilities.setInstance(new SgdTestCryptoUtilities());
    }

    @Test
    public void shouldExtractTelematikId_EvenWithAdmissionAuthorityPresent() {
        final X509Certificate certificate = SgdCryptoUtilities.getInstance()
                .loadX509CertificateFromP12File("src/test/resources/keys/smcb/smcb_mit_admission_authority.p12", "00");

        assertThat(SgdCryptoUtilities.getInstance().extractTelematikIdFromCertificate(certificate))
                .contains("2-2-EPA-833621999741663");
    }

    @Test
    public void shouldExtractTelematikId_WithoutAdmissionAuthorityPresent() {
        final X509Certificate certificate = SgdCryptoUtilities.getInstance()
                .loadX509CertificateFromP12File("src/test/resources/keys/smcb/833621999741621_c.hci.aut-arge-psych-ecc.p12", "00");

        assertThat(SgdCryptoUtilities.getInstance().extractTelematikIdFromCertificate(certificate))
                .contains("1-2-EPA-833621999741621");
    }
}