/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.domain.sgdCommunication;

import de.gematik.ti.sgd.SgdTestCryptoUtilities;
import de.gematik.ti.sgd.crypto.SgdCryptoUtilities;
import org.junit.Test;

import java.io.File;
import java.security.PublicKey;

import static org.assertj.core.api.Assertions.assertThat;

public class PublicKeyEciesTest {
    private final String SGD_P12_FILENAME = "src/test/resources/keys/sgd/c.sgd1.hsm-aut-ecc.p12";

    {
        SgdCryptoUtilities.setInstance(new SgdTestCryptoUtilities());
    }

    //A_17894
    @Test
    public void checkPublicKeySerializationForm_ShouldMatchSpecification() {
        PublicKey publicKey = SgdCryptoUtilities.getInstance().loadX509CertificateFromP12File(SGD_P12_FILENAME, "00").getPublicKey();

        PublicKeyEcies publicKeyEcies = new PublicKeyEcies(publicKey);




        assertThat(publicKeyEcies.getMessage())
                .matches("brainpoolP256r1 0x[0-9a-f]{64} 0x[0-9a-f]{64}");
    }
}
